@@ -1,3 +1,4 @@
+/* -*- mode: c; c-basic-offset: 4; indent-tabs-mode: nil -*- */
 /*
  * kadmin/dbutil/kdb5_create.c
  *
@@ -8,7 +9,7 @@
  *   require a specific license from the United States Government.
  *   It is the responsibility of any person or organization contemplating
  *   export to obtain such a license before exporting.
- * 
+ *
  * WITHIN THAT CONSTRAINT, permission to use, copy, modify, and
  * distribute this software and its documentation for any purpose and
  * without fee is hereby granted, provided that the above copyright
@@ -22,21 +23,21 @@
  * M.I.T. makes no representations about the suitability of
  * this software for any purpose.  It is provided "as is" without express
  * or implied warranty.
- * 
+ *
  *
  * Generate (from scratch) a Kerberos KDC database.
  */
 
 /*
  * Copyright (C) 1998 by the FundsXpress, INC.
- * 
+ *
  * All rights reserved.
- * 
+ *
  * Export of this software from the United States of America may require
  * a specific license from the United States Government.  It is the
  * responsibility of any person or organization contemplating export to
  * obtain such a license before exporting.
- * 
+ *
  * WITHIN THAT CONSTRAINT, permission to use, copy, modify, and
  * distribute this software and its documentation for any purpose and
  * without fee is hereby granted, provided that the above copyright
@@ -47,7 +48,7 @@
  * permission.  FundsXpress makes no representations about the suitability of
  * this software for any purpose.  It is provided "as is" without express
  * or implied warranty.
- * 
+ *
  * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
  * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -66,9 +67,9 @@
 #include "kdb5_util.h"
 
 enum ap_op {
-    NULL_KEY,				/* setup null keys */
-    MASTER_KEY,				/* use master key as new key */
-    TGT_KEY				/* special handling for tgt key */
+    NULL_KEY,                           /* setup null keys */
+    MASTER_KEY,                         /* use master key as new key */
+    TGT_KEY                             /* special handling for tgt key */
 };
 
 krb5_key_salt_tuple def_kslist = { ENCTYPE_DES_CBC_CRC, KRB5_KDB_SALTTYPE_NORMAL };
@@ -92,16 +93,16 @@ struct realm_info {
 };
 
 struct iterate_args {
-    krb5_context	ctx;
-    struct realm_info	*rblock;
-    krb5_db_entry	*dbentp;
+    krb5_context        ctx;
+    struct realm_info   *rblock;
+    krb5_db_entry       *dbentp;
 };
 
-static krb5_error_code add_principal 
-	(krb5_context,
-	 krb5_principal,
-	 enum ap_op,
-	 struct realm_info *);
+static krb5_error_code add_principal
+(krb5_context,
+ krb5_principal,
+ enum ap_op,
+ struct realm_info *);
 
 /*
  * Steps in creating a database:
@@ -122,28 +123,28 @@ extern krb5_principal master_princ;
 krb5_data master_salt;
 
 krb5_data tgt_princ_entries[] = {
-	{0, KRB5_TGS_NAME_SIZE, KRB5_TGS_NAME},
-	{0, 0, 0} };
+    {0, KRB5_TGS_NAME_SIZE, KRB5_TGS_NAME},
+    {0, 0, 0} };
 
 krb5_data db_creator_entries[] = {
-	{0, sizeof("db_creation")-1, "db_creation"} };
+    {0, sizeof("db_creation")-1, "db_creation"} };
 
 /* XXX knows about contents of krb5_principal, and that tgt names
- are of form TGT/REALM@REALM */
+   are of form TGT/REALM@REALM */
 krb5_principal_data tgt_princ = {
-        0,					/* magic number */
-	{0, 0, 0},				/* krb5_data realm */
-	tgt_princ_entries,			/* krb5_data *data */
-	2,					/* int length */
-	KRB5_NT_SRV_INST			/* int type */
+    0,                                      /* magic number */
+    {0, 0, 0},                              /* krb5_data realm */
+    tgt_princ_entries,                      /* krb5_data *data */
+    2,                                      /* int length */
+    KRB5_NT_SRV_INST                        /* int type */
 };
 
 krb5_principal_data db_create_princ = {
-        0,					/* magic number */
-	{0, 0, 0},				/* krb5_data realm */
-	db_creator_entries,			/* krb5_data *data */
-	1,					/* int length */
-	KRB5_NT_SRV_INST			/* int type */
+    0,                                      /* magic number */
+    {0, 0, 0},                              /* krb5_data realm */
+    db_creator_entries,                     /* krb5_data *data */
+    1,                                      /* int length */
+    KRB5_NT_SRV_INST                        /* int type */
 };
 
 extern char *mkey_password;
@@ -154,8 +155,8 @@ extern kadm5_config_params global_params;
 extern krb5_context util_context;
 
 void kdb5_create(argc, argv)
-   int argc;
-   char *argv[];
+    int argc;
+    char *argv[];
 {
     int optchar;
 
@@ -168,26 +169,26 @@ void kdb5_create(argc, argv)
     kdb_log_context *log_ctx;
     krb5_kvno mkey_kvno;
     int strong_random = 1;
-	   
+
     while ((optchar = getopt(argc, argv, "sW")) != -1) {
-	switch(optchar) {
-	case 's':
-	    do_stash++;
-	    break;
-	case 'h':
-	    if (!add_db_arg("hash=true")) {
-		com_err(progname, ENOMEM, "while parsing command arguments\n");
-		exit(1);
-	    }
-	    break;
-	case 'W':
-	    strong_random = 0;
-	    break;
-	case '?':
-	default:
-	    usage();
-	    return;
-	}
+        switch(optchar) {
+        case 's':
+            do_stash++;
+            break;
+        case 'h':
+            if (!add_db_arg("hash=true")) {
+                com_err(progname, ENOMEM, "while parsing command arguments\n");
+                exit(1);
+            }
+            break;
+        case 'W':
+            strong_random = 0;
+            break;
+        case '?':
+        default:
+            usage();
+            return;
+        }
     }
 
     rblock.max_life = global_params.max_life;
@@ -202,18 +203,18 @@ void kdb5_create(argc, argv)
     printf ("Loading random data\n");
     retval = krb5_c_random_os_entropy (util_context, strong_random, NULL);
     if (retval) {
-      com_err (progname, retval, "Loading random data");
-      exit_status++; return;
+        com_err (progname, retval, "Loading random data");
+        exit_status++; return;
     }
-    
+
     /* assemble & parse the master key name */
 
     if ((retval = krb5_db_setup_mkey_name(util_context,
-					  global_params.mkey_name,
-					  global_params.realm,  
-					  &mkey_fullname, &master_princ))) {
-	com_err(progname, retval, "while setting up master key name");
-	exit_status++; return;
+                                          global_params.mkey_name,
+                                          global_params.realm,
+                                          &mkey_fullname, &master_princ))) {
+        com_err(progname, retval, "while setting up master key name");
+        exit_status++; return;
     }
 
     krb5_princ_set_realm_data(util_context, &db_create_princ, global_params.realm);
@@ -225,42 +226,42 @@ void kdb5_create(argc, argv)
 
     printf("Initializing database '%s' for realm '%s',\n\
 master key name '%s'\n",
-	   global_params.dbname, global_params.realm, mkey_fullname);
+           global_params.dbname, global_params.realm, mkey_fullname);
 
     if (!mkey_password) {
-	printf("You will be prompted for the database Master Password.\n");
-	printf("It is important that you NOT FORGET this password.\n");
-	fflush(stdout);
+        printf("You will be prompted for the database Master Password.\n");
+        printf("It is important that you NOT FORGET this password.\n");
+        fflush(stdout);
 
-	pw_size = 1024;
-	pw_str = malloc(pw_size);
-	if (pw_str == NULL) {
-	    com_err(progname, ENOMEM, "while creating new master key");
-	    exit_status++; return;
-	}
-	
-	retval = krb5_read_password(util_context, KRB5_KDC_MKEY_1, KRB5_KDC_MKEY_2,
-				    pw_str, &pw_size);
-	if (retval) {
-	    com_err(progname, retval, "while reading master key from keyboard");
-	    exit_status++; return;
-	}
-	mkey_password = pw_str;
+        pw_size = 1024;
+        pw_str = malloc(pw_size);
+        if (pw_str == NULL) {
+            com_err(progname, ENOMEM, "while creating new master key");
+            exit_status++; return;
+        }
+
+        retval = krb5_read_password(util_context, KRB5_KDC_MKEY_1, KRB5_KDC_MKEY_2,
+                                    pw_str, &pw_size);
+        if (retval) {
+            com_err(progname, retval, "while reading master key from keyboard");
+            exit_status++; return;
+        }
+        mkey_password = pw_str;
     }
 
     pwd.data = mkey_password;
     pwd.length = strlen(mkey_password);
     retval = krb5_principal2salt(util_context, master_princ, &master_salt);
     if (retval) {
-	com_err(progname, retval, "while calculating master key salt");
-	exit_status++; return;
+        com_err(progname, retval, "while calculating master key salt");
+        exit_status++; return;
     }
 
-    retval = krb5_c_string_to_key(util_context, master_keyblock.enctype, 
-				  &pwd, &master_salt, &master_keyblock);
+    retval = krb5_c_string_to_key(util_context, master_keyblock.enctype,
+                                  &pwd, &master_salt, &master_keyblock);
     if (retval) {
-	com_err(progname, retval, "while transforming master key from password");
-	exit_status++; return;
+        com_err(progname, retval, "while transforming master key from password");
+        exit_status++; return;
     }
 
     rblock.key = &master_keyblock;
@@ -269,59 +270,59 @@ master key name '%s'\n",
     seed.data = master_keyblock.contents;
 
     if ((retval = krb5_c_random_seed(util_context, &seed))) {
-	com_err(progname, retval, "while initializing random key generator");
-	exit_status++; return;
+        com_err(progname, retval, "while initializing random key generator");
+        exit_status++; return;
     }
     if ((retval = krb5_db_create(util_context,
-				 db5util_db_args))) {
-	com_err(progname, retval, "while creating database '%s'",
-		global_params.dbname);
-	exit_status++; return;
+                                 db5util_db_args))) {
+        com_err(progname, retval, "while creating database '%s'",
+                global_params.dbname);
+        exit_status++; return;
     }
 /*     if ((retval = krb5_db_fini(util_context))) { */
 /*         com_err(progname, retval, "while closing current database"); */
 /*         exit_status++; return; */
 /*     } */
 /*     if ((retval = krb5_db_open(util_context, db5util_db_args, KRB5_KDB_OPEN_RW))) { */
-/* 	com_err(progname, retval, "while initializing the database '%s'", */
-/* 		global_params.dbname); */
-/* 	exit_status++; return; */
+/*      com_err(progname, retval, "while initializing the database '%s'", */
+/*              global_params.dbname); */
+/*      exit_status++; return; */
 /*     } */
 
     if (log_ctx && log_ctx->iproprole) {
-	    if ((retval = ulog_map(util_context, global_params.iprop_logfile,
-				   global_params.iprop_ulogsize, FKCOMMAND,
-				   db5util_db_args))) {
-	    com_err(argv[0], retval,
-		    _("while creating update log"));
-	    exit_status++;
-	    return;
-	}
+        if ((retval = ulog_map(util_context, global_params.iprop_logfile,
+                               global_params.iprop_ulogsize, FKCOMMAND,
+                               db5util_db_args))) {
+            com_err(argv[0], retval,
+                    _("while creating update log"));
+            exit_status++;
+            return;
+        }
 
-	/*
-	 * We're reinitializing the update log in case one already
-	 * existed, but this should never happen.
-	 */
-	(void) memset(log_ctx->ulog, 0, sizeof (kdb_hlog_t));
+        /*
+         * We're reinitializing the update log in case one already
+         * existed, but this should never happen.
+         */
+        (void) memset(log_ctx->ulog, 0, sizeof (kdb_hlog_t));
 
-	log_ctx->ulog->kdb_hmagic = KDB_ULOG_HDR_MAGIC;
-	log_ctx->ulog->db_version_num = KDB_VERSION;
-	log_ctx->ulog->kdb_state = KDB_STABLE;
-	log_ctx->ulog->kdb_block = ULOG_BLOCK;
+        log_ctx->ulog->kdb_hmagic = KDB_ULOG_HDR_MAGIC;
+        log_ctx->ulog->db_version_num = KDB_VERSION;
+        log_ctx->ulog->kdb_state = KDB_STABLE;
+        log_ctx->ulog->kdb_block = ULOG_BLOCK;
 
-	/*
-	 * Since we're creating a new db we shouldn't worry about
-	 * adding the initial principals since any slave might as well
-	 * do full resyncs from this newly created db.
-	 */
-	log_ctx->iproprole = IPROP_NULL;
+        /*
+         * Since we're creating a new db we shouldn't worry about
+         * adding the initial principals since any slave might as well
+         * do full resyncs from this newly created db.
+         */
+        log_ctx->iproprole = IPROP_NULL;
     }
 
     if ((retval = add_principal(util_context, master_princ, MASTER_KEY, &rblock)) ||
-	(retval = add_principal(util_context, &tgt_princ, TGT_KEY, &rblock))) {
-	(void) krb5_db_fini(util_context);
-	com_err(progname, retval, "while adding entries to the database");
-	exit_status++; return;
+        (retval = add_principal(util_context, &tgt_princ, TGT_KEY, &rblock))) {
+        (void) krb5_db_fini(util_context);
+        com_err(progname, retval, "while adding entries to the database");
+        exit_status++; return;
     }
 
 
@@ -342,29 +343,29 @@ master key name '%s'\n",
         mkey_kvno = 1;  /* Default */
 
     retval = krb5_db_store_master_key(util_context,
-				      global_params.stash_file,
-				      master_princ,
-				      mkey_kvno,
-				      &master_keyblock,
-				      mkey_password);
+                                      global_params.stash_file,
+                                      master_princ,
+                                      mkey_kvno,
+                                      &master_keyblock,
+                                      mkey_password);
     if (retval) {
-	com_err(progname, errno, "while storing key");
-	printf("Warning: couldn't stash master key.\n");
+        com_err(progname, errno, "while storing key");
+        printf("Warning: couldn't stash master key.\n");
     }
     /* clean up */
     (void) krb5_db_fini(util_context);
-    memset((char *)master_keyblock.contents, 0, master_keyblock.length);
+    memset(master_keyblock.contents, 0, master_keyblock.length);
     free(master_keyblock.contents);
     if (pw_str) {
-	memset(pw_str, 0, pw_size);
-	free(pw_str);
+        memset(pw_str, 0, pw_size);
+        free(pw_str);
     }
     free(master_salt.data);
 
     if (kadm5_create(&global_params)) {
-	 if (!do_stash) unlink(global_params.stash_file);
-	 exit_status++;
-	 return;
+        if (!do_stash) unlink(global_params.stash_file);
+        exit_status++;
+        return;
     }
     if (!do_stash) unlink(global_params.stash_file);
 
@@ -373,15 +374,15 @@ master key name '%s'\n",
 
 static krb5_error_code
 tgt_keysalt_iterate(ksent, ptr)
-    krb5_key_salt_tuple	*ksent;
-    krb5_pointer	ptr;
+    krb5_key_salt_tuple *ksent;
+    krb5_pointer        ptr;
 {
-    krb5_context	context;
-    krb5_error_code	kret;
-    struct iterate_args	*iargs;
-    krb5_keyblock	key;
-    krb5_int32		ind;
-    krb5_data	pwd;
+    krb5_context        context;
+    krb5_error_code     kret;
+    struct iterate_args *iargs;
+    krb5_keyblock       key;
+    krb5_int32          ind;
+    krb5_data   pwd;
 
     iargs = (struct iterate_args *) ptr;
     kret = 0;
@@ -396,20 +397,20 @@ tgt_keysalt_iterate(ksent, ptr)
     pwd.length = strlen(mkey_password);
     kret = krb5_c_random_seed(context, &pwd);
     if (kret)
-	return kret;
+        return kret;
 
     if (!(kret = krb5_dbe_create_key_data(iargs->ctx, iargs->dbentp))) {
-	ind = iargs->dbentp->n_key_data-1;
-	if (!(kret = krb5_c_make_random_key(context, ksent->ks_enctype,
-					    &key))) {
-	    kret = krb5_dbekd_encrypt_key_data(context,
-					       iargs->rblock->key,
-					       &key, 
-					       NULL,
-					       1,
-					       &iargs->dbentp->key_data[ind]);
-	    krb5_free_keyblock_contents(context, &key);
-	}
+        ind = iargs->dbentp->n_key_data-1;
+        if (!(kret = krb5_c_make_random_key(context, ksent->ks_enctype,
+                                            &key))) {
+            kret = krb5_dbekd_encrypt_key_data(context,
+                                               iargs->rblock->key,
+                                               &key,
+                                               NULL,
+                                               1,
+                                               &iargs->dbentp->key_data[ind]);
+            krb5_free_keyblock_contents(context, &key);
+        }
     }
 
     return(kret);
@@ -422,15 +423,15 @@ add_principal(context, princ, op, pblock)
     enum ap_op op;
     struct realm_info *pblock;
 {
-    krb5_error_code 	  retval;
-    krb5_db_entry 	  entry;
+    krb5_error_code       retval;
+    krb5_db_entry         entry;
     krb5_kvno             mkey_kvno;
-    krb5_timestamp	  now;
-    struct iterate_args	  iargs;
-    int			  nentries = 1;
+    krb5_timestamp        now;
+    struct iterate_args   iargs;
+    int                   nentries = 1;
     krb5_actkvno_node     actkvno;
 
-    memset((char *) &entry, 0, sizeof(entry));
+    memset(&entry, 0, sizeof(entry));
 
     entry.len = KRB5_KDB_V1_BASE_LENGTH;
     entry.attributes = pblock->flags;
@@ -439,32 +440,32 @@ add_principal(context, princ, op, pblock)
     entry.expiration = pblock->expiration;
 
     if ((retval = krb5_copy_principal(context, princ, &entry.princ)))
-	goto error_out;
+        goto error_out;
 
     if ((retval = krb5_timeofday(context, &now)))
-	goto error_out;
+        goto error_out;
 
     if ((retval = krb5_dbe_update_mod_princ_data(context, &entry,
-						 now, &db_create_princ)))
-	goto error_out;
+                                                 now, &db_create_princ)))
+        goto error_out;
 
     switch (op) {
     case MASTER_KEY:
-	if ((entry.key_data=(krb5_key_data*)malloc(sizeof(krb5_key_data)))
-	    == NULL)
-	    goto error_out;
-	memset((char *) entry.key_data, 0, sizeof(krb5_key_data));
-	entry.n_key_data = 1;
+        if ((entry.key_data=(krb5_key_data*)malloc(sizeof(krb5_key_data)))
+            == NULL)
+            goto error_out;
+        memset(entry.key_data, 0, sizeof(krb5_key_data));
+        entry.n_key_data = 1;
 
         if (global_params.mask & KADM5_CONFIG_KVNO)
             mkey_kvno = global_params.kvno; /* user specified */
         else
             mkey_kvno = 1;  /* Default */
-	entry.attributes |= KRB5_KDB_DISALLOW_ALL_TIX;
-	if ((retval = krb5_dbekd_encrypt_key_data(context, pblock->key,
-						  &master_keyblock, NULL, 
-						  mkey_kvno, entry.key_data)))
-	    return retval;
+        entry.attributes |= KRB5_KDB_DISALLOW_ALL_TIX;
+        if ((retval = krb5_dbekd_encrypt_key_data(context, pblock->key,
+                                                  &master_keyblock, NULL,
+                                                  mkey_kvno, entry.key_data)))
+            return retval;
         /*
          * There should always be at least one "active" mkey so creating the
          * KRB5_TL_ACTKVNO entry now so the initial mkey is active.
@@ -480,30 +481,30 @@ add_principal(context, princ, op, pblock)
         if ((retval = krb5_dbe_update_mkvno(context, &entry, mkey_kvno)))
             return retval;
 
-	break;
+        break;
     case TGT_KEY:
-	iargs.ctx = context;
-	iargs.rblock = pblock;
-	iargs.dbentp = &entry;
-	/*
-	 * Iterate through the key/salt list, ignoring salt types.
-	 */
-	if ((retval = krb5_keysalt_iterate(pblock->kslist,
-					   pblock->nkslist,
-					   1,
-					   tgt_keysalt_iterate,
-					   (krb5_pointer) &iargs)))
-	    return retval;
-	break;
+        iargs.ctx = context;
+        iargs.rblock = pblock;
+        iargs.dbentp = &entry;
+        /*
+         * Iterate through the key/salt list, ignoring salt types.
+         */
+        if ((retval = krb5_keysalt_iterate(pblock->kslist,
+                                           pblock->nkslist,
+                                           1,
+                                           tgt_keysalt_iterate,
+                                           (krb5_pointer) &iargs)))
+            return retval;
+        break;
     case NULL_KEY:
-	return EOPNOTSUPP;
+        return EOPNOTSUPP;
     default:
-	break;
+        break;
     }
 
     entry.mask = (KADM5_KEY_DATA | KADM5_PRINCIPAL | KADM5_ATTRIBUTES |
-	KADM5_MAX_LIFE | KADM5_MAX_RLIFE | KADM5_TL_DATA |
-	KADM5_PRINC_EXPIRE_TIME);
+                  KADM5_MAX_LIFE | KADM5_MAX_RLIFE | KADM5_TL_DATA |
+                  KADM5_PRINC_EXPIRE_TIME);
 
     retval = krb5_db_put_principal(context, &entry, &nentries);
 
