@@ -52,7 +52,7 @@
  */
 #define KRB5_MAJOR_RELEASE 1
 #define KRB5_MINOR_RELEASE 8
-#define KRB5_PATCHLEVEL 0
+#define KRB5_PATCHLEVEL 1
 /* #undef KRB5_RELTAIL */
-#define KRB5_RELDATE "20100302"
-#define KRB5_RELTAG "tags/krb5-1-8-final"
+#define KRB5_RELDATE "20100408"
+#define KRB5_RELTAG "tags/krb5-1-8-1-final"
